# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: masterful/proto/metrics.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='masterful/proto/metrics.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1dmasterful/proto/metrics.proto\"\xd9\x03\n\x07Metrics\x12\x0c\n\x04loss\x18\x01 \x01(\x02\x12\x36\n\x10label_recall_map\x18\x02 \x03(\x0b\x32\x1c.Metrics.LabelRecallMapEntry\x12<\n\x13label_precision_map\x18\x03 \x03(\x0b\x32\x1f.Metrics.LabelPrecisionMapEntry\x12\x37\n\x10\x63onfusion_matrix\x18\x04 \x03(\x0b\x32\x1d.Metrics.ConfusionMatrixEntry\x12\x15\n\rbinary_recall\x18\x05 \x01(\x02\x12\x18\n\x10\x62inary_precision\x18\x06 \x01(\x02\x12\x17\n\x0f\x62inary_f1_score\x18\x07 \x01(\x02\x12\x12\n\nerror_rate\x18\x08 \x01(\x02\x1a\x35\n\x13LabelRecallMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x1a\x38\n\x16LabelPrecisionMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x1a\x42\n\x14\x43onfusionMatrixEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x19\n\x05value\x18\x02 \x01(\x0b\x32\n.Int32List:\x02\x38\x01\"\x1b\n\tInt32List\x12\x0e\n\x06values\x18\x01 \x03(\x05\x62\x06proto3')
)




_METRICS_LABELRECALLMAPENTRY = _descriptor.Descriptor(
  name='LabelRecallMapEntry',
  full_name='Metrics.LabelRecallMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Metrics.LabelRecallMapEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='Metrics.LabelRecallMapEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=381,
)

_METRICS_LABELPRECISIONMAPENTRY = _descriptor.Descriptor(
  name='LabelPrecisionMapEntry',
  full_name='Metrics.LabelPrecisionMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Metrics.LabelPrecisionMapEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='Metrics.LabelPrecisionMapEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=383,
  serialized_end=439,
)

_METRICS_CONFUSIONMATRIXENTRY = _descriptor.Descriptor(
  name='ConfusionMatrixEntry',
  full_name='Metrics.ConfusionMatrixEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Metrics.ConfusionMatrixEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='Metrics.ConfusionMatrixEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=441,
  serialized_end=507,
)

_METRICS = _descriptor.Descriptor(
  name='Metrics',
  full_name='Metrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='loss', full_name='Metrics.loss', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_recall_map', full_name='Metrics.label_recall_map', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_precision_map', full_name='Metrics.label_precision_map', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='confusion_matrix', full_name='Metrics.confusion_matrix', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary_recall', full_name='Metrics.binary_recall', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary_precision', full_name='Metrics.binary_precision', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary_f1_score', full_name='Metrics.binary_f1_score', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_rate', full_name='Metrics.error_rate', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_METRICS_LABELRECALLMAPENTRY, _METRICS_LABELPRECISIONMAPENTRY, _METRICS_CONFUSIONMATRIXENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=507,
)


_INT32LIST = _descriptor.Descriptor(
  name='Int32List',
  full_name='Int32List',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='Int32List.values', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=509,
  serialized_end=536,
)

_METRICS_LABELRECALLMAPENTRY.containing_type = _METRICS
_METRICS_LABELPRECISIONMAPENTRY.containing_type = _METRICS
_METRICS_CONFUSIONMATRIXENTRY.fields_by_name['value'].message_type = _INT32LIST
_METRICS_CONFUSIONMATRIXENTRY.containing_type = _METRICS
_METRICS.fields_by_name['label_recall_map'].message_type = _METRICS_LABELRECALLMAPENTRY
_METRICS.fields_by_name['label_precision_map'].message_type = _METRICS_LABELPRECISIONMAPENTRY
_METRICS.fields_by_name['confusion_matrix'].message_type = _METRICS_CONFUSIONMATRIXENTRY
DESCRIPTOR.message_types_by_name['Metrics'] = _METRICS
DESCRIPTOR.message_types_by_name['Int32List'] = _INT32LIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Metrics = _reflection.GeneratedProtocolMessageType('Metrics', (_message.Message,), {

  'LabelRecallMapEntry' : _reflection.GeneratedProtocolMessageType('LabelRecallMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _METRICS_LABELRECALLMAPENTRY,
    '__module__' : 'masterful.proto.metrics_pb2'
    # @@protoc_insertion_point(class_scope:Metrics.LabelRecallMapEntry)
    })
  ,

  'LabelPrecisionMapEntry' : _reflection.GeneratedProtocolMessageType('LabelPrecisionMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _METRICS_LABELPRECISIONMAPENTRY,
    '__module__' : 'masterful.proto.metrics_pb2'
    # @@protoc_insertion_point(class_scope:Metrics.LabelPrecisionMapEntry)
    })
  ,

  'ConfusionMatrixEntry' : _reflection.GeneratedProtocolMessageType('ConfusionMatrixEntry', (_message.Message,), {
    'DESCRIPTOR' : _METRICS_CONFUSIONMATRIXENTRY,
    '__module__' : 'masterful.proto.metrics_pb2'
    # @@protoc_insertion_point(class_scope:Metrics.ConfusionMatrixEntry)
    })
  ,
  'DESCRIPTOR' : _METRICS,
  '__module__' : 'masterful.proto.metrics_pb2'
  # @@protoc_insertion_point(class_scope:Metrics)
  })
_sym_db.RegisterMessage(Metrics)
_sym_db.RegisterMessage(Metrics.LabelRecallMapEntry)
_sym_db.RegisterMessage(Metrics.LabelPrecisionMapEntry)
_sym_db.RegisterMessage(Metrics.ConfusionMatrixEntry)

Int32List = _reflection.GeneratedProtocolMessageType('Int32List', (_message.Message,), {
  'DESCRIPTOR' : _INT32LIST,
  '__module__' : 'masterful.proto.metrics_pb2'
  # @@protoc_insertion_point(class_scope:Int32List)
  })
_sym_db.RegisterMessage(Int32List)


_METRICS_LABELRECALLMAPENTRY._options = None
_METRICS_LABELPRECISIONMAPENTRY._options = None
_METRICS_CONFUSIONMATRIXENTRY._options = None
# @@protoc_insertion_point(module_scope)



# Generated by Django 3.2 on 2021-09-18 16:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0004_auto_20210917_1440'),
    ]

    operations = [
        migrations.AddField(
            model_name='policysearchtask',
            name='engine_version',
            field=models.CharField(default='', max_length=100),
        ),
    ]



"""Defines Visualize's policy scanner functionality.

This module implements the functionality for Visualzie to scan for
serialized search_task_pb2.PolicySearchTask serialized protos produced by
Masterful.
"""

import os
import pkg_resources
import pathlib

import google.protobuf.json_format as json_format

from masterful_gui.backend.apps.api import models
from masterful_gui.backend.proto import search_task_pb2

# The location where the scanner should look for serialzed policies.
_SCAN_DIR = f'{os.path.expanduser("~")}/.masterful/policies'

# The extension of a serialized policy proto file. The extension actually
# makes no difference, this is just to facilitate identifying the right files
# to read.
# WARNING: This matches the configuration of proto_serializer module in
# masterful_partners repo. You must change them both or you'll break
# assumptions and Visualize.
_EXTENSION = "pstpb"

_SAMPLE_POLICY_NAME = "Sample run"
_SAMPLE_POLICY_FILE_NAME = "sample_policy"


def scan():
  """Scans the configured directory for serlized policy protos.
  
  This function deserializes policy protos on disk, converts them
  to Django's owm policy model, and persists them to the database (app model).
  If the database already had a record for that policy, it updates
  that records with the values extracted from the serialized policy. If it
  wasn't, this will persist it to the database.
  """
  _load_sample_policy()

  pathlib.Path(_SCAN_DIR).mkdir(parents=True, exist_ok=True)

  if len(os.listdir(_SCAN_DIR)) == 0:
    #TODO(ray): Consider printing something to show in backend logs.
    return

  serialized_tasks = []
  for file in os.listdir(_SCAN_DIR):
    if file.split('.')[-1] != _EXTENSION:
      continue
    serialized_tasks.append(file)

  if len(serialized_tasks) == 0:
    return

  for serialized_task in serialized_tasks:
    task = search_task_pb2.PolicySearchTask()
    file_name = f'{_SCAN_DIR}/{serialized_task}'
    with open(file_name, "rb") as f:
      task.ParseFromString(f.read())

    task_dict = json_format.MessageToDict(task,
                                          use_integers_for_enums=False,
                                          including_default_value_fields=True,
                                          preserving_proto_field_name=True)

    task_exists = len(
        models.PolicySearchTask.objects.filter(pk=task.policy_name)) > 0
    if task_exists:
      existing_task = models.PolicySearchTask.objects.get(pk=task.policy_name)
      existing_task.approach_name = task.approach_name
      existing_task.presearch_model_val_metrics = task_dict.get(
          "presearch_model_val_metrics", {})
      existing_task.node_search_tasks = task_dict.get("node_search_tasks", {})
      existing_task.engine_version = task.engine_version
      existing_task.fit_was_captured = task.fit_was_captured
      existing_task.learned_policy_val_metrics = task_dict.get(
          "learned_policy_val_metrics", {})
      existing_task.task_type = task_dict.get("task_type")
      existing_task.save()

    else:
      new_task = models.PolicySearchTask.objects.create(
          policy_name=task.policy_name,
          approach_name=task.approach_name,
          presearch_model_val_metrics=task_dict.get(
              "presearch_model_val_metrics", {}),
          node_search_tasks=task_dict.get("node_search_tasks", {}),
          engine_version=task.engine_version,
          fit_was_captured=task.fit_was_captured,
          learned_policy_val_metrics=task_dict.get("learned_policy_val_metrics",
                                                   {}),
          task_type=task_dict.get("task_type"))
      new_task.save()


def _load_sample_policy():
  """Loads the data for a sample policy into the model."""
  loaded_already = len(
      models.PolicySearchTask.objects.filter(pk=_SAMPLE_POLICY_NAME)) > 0

  if loaded_already:
    return

  sample_proto = search_task_pb2.PolicySearchTask()
  data = pkg_resources.resource_string("masterful_gui",
                                       f'data/{_SAMPLE_POLICY_FILE_NAME}')
  sample_proto.ParseFromString(data)

  proto_dict = json_format.MessageToDict(sample_proto,
                                         use_integers_for_enums=False,
                                         including_default_value_fields=True,
                                         preserving_proto_field_name=True)

  model_entry = models.PolicySearchTask.objects.create(
      policy_name=sample_proto.policy_name,
      approach_name=sample_proto.approach_name,
      presearch_model_val_metrics=proto_dict.get("presearch_model_val_metrics",
                                                 {}),
      node_search_tasks=proto_dict.get("node_search_tasks", {}),
      engine_version=sample_proto.engine_version,
      fit_was_captured=sample_proto.fit_was_captured,
      learned_policy_val_metrics=proto_dict.get("learned_policy_val_metrics",
                                                {}),
      task_type=proto_dict.get("task_type"))

  model_entry.save()


"""Masterful GUI WSGI application module.

Provides access to the WSGI app object that should be executed. The WSGI
application object is implemented in Django, this module passes that object
as is to the program.

Note: The settings module environment variable must be configured prior to
creating the WSGI app object.

For more info on Django's WSGI application object, see:
https://docs.djangoproject.com/en/3.2/howto/deployment/wsgi/#the-application-object
"""
import os
import tempfile

from django.core.wsgi import get_wsgi_application
from django.core import management

# The name of the Django settings module.
_DJANGO_SETTINGS_MODULE_NAME = 'DJANGO_SETTINGS_MODULE'

# The relative path to the settings module. This is tied closely to Django
# environment setup, if project structure is changed this must be changed as
# well.
_DJANGO_SETTINGS_MODULE_PATH = 'masterful_gui.backend.settings'


def init_settings_env_variable():
  """Initializes the settings module variable in the environment.
  
  Must be called before creating the WSGI app or it'll fail.
  """
  os.environ.setdefault(_DJANGO_SETTINGS_MODULE_NAME,
                        _DJANGO_SETTINGS_MODULE_PATH)


def make_migrations():
  """Checks for model updates to create the necessary SQL updates."""
  # TODO(ray): Replace this tempfile stratefy with an official logging solution.
  # This is a placeholder technique to intercept the output of some django
  # commands before stdout to reduce the noise of the running server.
  tmp_log_file = tempfile.mkstemp()[1]
  with open(tmp_log_file, 'w') as tf:
    management.call_command('makemigrations', stdout=tf)


def migrate():
  """Applies pending SQL statements by 'makemigrations' in the database."""
  # TODO(ray): Replace this tempfile stratefy with an official logging solution.
  # This is a placeholder technique to intercept the output of some django
  # commands before stdout to reduce the noise of the running server.
  tmp_log_file = tempfile.mkstemp()[1]
  with open(tmp_log_file, 'w') as tf:
    management.call_command('migrate', stdout=tf)


def create_wsgi_app():
  """Creates a Masterful GUI WSGI app instance.
  
  As mentioned in the module docstring this only calls the Django API to obtain
  the predefined WSGI app object. You must call `init_settings_env_variable`
  before calling this function.
  
  Returns:
    The WSGI app instance..
  """
  return get_wsgi_application()


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: masterful/proto/dataset.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from masterful_gui.backend.proto import metadata_pb2 as masterful_dot_proto_dot_metadata__pb2
from masterful_gui.backend.proto import params_pb2 as masterful_dot_proto_dot_params__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='masterful/proto/dataset.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1dmasterful/proto/dataset.proto\x1a\x1emasterful/proto/metadata.proto\x1a\x1cmasterful/proto/params.proto\"\x9d\x02\n\x07\x44\x61taset\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05split\x18\x03 \x01(\t\x12\x13\n\x0bnum_classes\x18\x04 \x01(\x05\x12\x0f\n\x07\x63v_task\x18\x05 \x01(\t\x12\x13\n\x0b\x63\x61rdinality\x18\x06 \x01(\x03\x12+\n\nlabels_map\x18\x07 \x03(\x0b\x32\x17.Dataset.LabelsMapEntry\x12\x31\n\x10\x61nalysis_results\x18\x08 \x01(\x0b\x32\x17.DatasetAnalysisResults\x12\x1b\n\x06params\x18\t \x01(\x0b\x32\x0b.DataParams\x1a\x30\n\x0eLabelsMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xea\x05\n\x16\x44\x61tasetAnalysisResults\x12\x16\n\x0etotal_examples\x18\x01 \x01(\x03\x12>\n\x0clabel_counts\x18\x02 \x03(\x0b\x32(.DatasetAnalysisResults.LabelCountsEntry\x12L\n\x13label_distributions\x18\x03 \x03(\x0b\x32/.DatasetAnalysisResults.LabelDistributionsEntry\x12\x10\n\x08\x62\x61lanced\x18\x04 \x01(\t\x12\x12\n\nmin_height\x18\x05 \x01(\x05\x12\x11\n\tmin_width\x18\x06 \x01(\x05\x12\x12\n\nmax_height\x18\x07 \x01(\x05\x12\x11\n\tmax_width\x18\x08 \x01(\x05\x12\x12\n\navg_height\x18\t \x01(\x05\x12\x11\n\tavg_width\x18\n \x01(\x05\x12\x15\n\rlargest_image\x18\x0b \x01(\t\x12\x16\n\x0esmallest_image\x18\x0c \x01(\t\x12\x17\n\x0f\x61vg_object_area\x18\r \x01(\t\x12\x1c\n\x14smallest_object_area\x18\x0e \x01(\t\x12\x1b\n\x13largest_object_area\x18\x0f \x01(\t\x12\x19\n\x11num_small_objects\x18\x10 \x01(\x03\x12\x1a\n\x12num_medium_objects\x18\x11 \x01(\x03\x12\x19\n\x11num_large_objects\x18\x12 \x01(\x03\x12\x18\n\x10num_empty_images\x18\x13 \x01(\x03\x12\x15\n\rtotal_objects\x18\x14 \x01(\x03\x12.\n\x12\x64uplicate_analysis\x18\x15 \x01(\x0b\x32\x12.DuplicateAnalysis\x1a\x32\n\x10LabelCountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x39\n\x17LabelDistributionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"q\n\x11\x44uplicateAnalysis\x12\x12\n\nduplicates\x18\x01 \x03(\t\x12\x18\n\x10\x64uplicates_count\x18\x02 \x01(\x05\x12\x17\n\x0fimage_path_type\x18\x03 \x01(\t\x12\x15\n\rduration_mins\x18\x04 \x01(\x05\"\xbb\x04\n\x05Split\x12$\n\nsplit_type\x18\x01 \x01(\x0e\x32\x10.Split.SplitType\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x63\x61rdinality\x18\x03 \x01(\x03\x12+\n\x0blabel_count\x18\x04 \x03(\x0b\x32\x16.Split.LabelCountEntry\x12\x39\n\x12label_distribution\x18\x05 \x03(\x0b\x32\x1d.Split.LabelDistributionEntry\x12\x1e\n\nimage_spec\x18\x06 \x01(\x0b\x32\n.ImageSpec\x12\x13\n\x0bnum_classes\x18\x07 \x01(\x05\x12\x12\n\nimbalanced\x18\x08 \x01(\x08\x12\x18\n\x10\x64uplicates_count\x18\t \x01(\x03\x12/\n\rimage_samples\x18\n \x03(\x0b\x32\x18.Split.ImageSamplesEntry\x1a\x31\n\x0fLabelCountEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x38\n\x16LabelDistributionEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x1a\x33\n\x11ImageSamplesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"J\n\tSplitType\x12\x16\n\x12SPLIT_TYPE_UNKNOWN\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\t\n\x05TRAIN\x10\x02\x12\x07\n\x03VAL\x10\x03\x12\x08\n\x04TEST\x10\x04\"\xdc\x03\n\rDatasetLegacy\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x1d\n\rtrain_dataset\x18\x03 \x01(\x0b\x32\x06.Split\x12\x1b\n\x0bval_dataset\x18\x04 \x01(\x0b\x32\x06.Split\x12\x1c\n\x0ctest_dataset\x18\x05 \x01(\x0b\x32\x06.Split\x12\x1c\n\x0c\x66ull_dataset\x18\x06 \x01(\x0b\x32\x06.Split\x12\x13\n\x0b\x63\x61rdinality\x18\x07 \x01(\x03\x12\x33\n\x0blabel_count\x18\x08 \x03(\x0b\x32\x1e.DatasetLegacy.LabelCountEntry\x12\x31\n\nlabels_map\x18\t \x03(\x0b\x32\x1d.DatasetLegacy.LabelsMapEntry\x12!\n\x04task\x18\n \x01(\x0e\x32\x13.ComputerVisionTask\x12\x13\n\x0bnum_classes\x18\x0b \x01(\x05\x12\x1e\n\x16\x61nalysis_duration_mins\x18\x0c \x01(\x02\x1a\x31\n\x0fLabelCountEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x30\n\x0eLabelsMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')
  ,
  dependencies=[masterful_dot_proto_dot_metadata__pb2.DESCRIPTOR,masterful_dot_proto_dot_params__pb2.DESCRIPTOR,])



_SPLIT_SPLITTYPE = _descriptor.EnumDescriptor(
  name='SplitType',
  full_name='Split.SplitType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SPLIT_TYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRAIN', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VAL', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEST', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1745,
  serialized_end=1819,
)
_sym_db.RegisterEnumDescriptor(_SPLIT_SPLITTYPE)


_DATASET_LABELSMAPENTRY = _descriptor.Descriptor(
  name='LabelsMapEntry',
  full_name='Dataset.LabelsMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Dataset.LabelsMapEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='Dataset.LabelsMapEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=333,
  serialized_end=381,
)

_DATASET = _descriptor.Descriptor(
  name='Dataset',
  full_name='Dataset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Dataset.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='Dataset.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='split', full_name='Dataset.split', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_classes', full_name='Dataset.num_classes', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cv_task', full_name='Dataset.cv_task', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cardinality', full_name='Dataset.cardinality', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels_map', full_name='Dataset.labels_map', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='analysis_results', full_name='Dataset.analysis_results', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='params', full_name='Dataset.params', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DATASET_LABELSMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=381,
)


_DATASETANALYSISRESULTS_LABELCOUNTSENTRY = _descriptor.Descriptor(
  name='LabelCountsEntry',
  full_name='DatasetAnalysisResults.LabelCountsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='DatasetAnalysisResults.LabelCountsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='DatasetAnalysisResults.LabelCountsEntry.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1021,
  serialized_end=1071,
)

_DATASETANALYSISRESULTS_LABELDISTRIBUTIONSENTRY = _descriptor.Descriptor(
  name='LabelDistributionsEntry',
  full_name='DatasetAnalysisResults.LabelDistributionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='DatasetAnalysisResults.LabelDistributionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='DatasetAnalysisResults.LabelDistributionsEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1073,
  serialized_end=1130,
)

_DATASETANALYSISRESULTS = _descriptor.Descriptor(
  name='DatasetAnalysisResults',
  full_name='DatasetAnalysisResults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_examples', full_name='DatasetAnalysisResults.total_examples', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_counts', full_name='DatasetAnalysisResults.label_counts', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_distributions', full_name='DatasetAnalysisResults.label_distributions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='balanced', full_name='DatasetAnalysisResults.balanced', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_height', full_name='DatasetAnalysisResults.min_height', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_width', full_name='DatasetAnalysisResults.min_width', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_height', full_name='DatasetAnalysisResults.max_height', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_width', full_name='DatasetAnalysisResults.max_width', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_height', full_name='DatasetAnalysisResults.avg_height', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_width', full_name='DatasetAnalysisResults.avg_width', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='largest_image', full_name='DatasetAnalysisResults.largest_image', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='smallest_image', full_name='DatasetAnalysisResults.smallest_image', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_object_area', full_name='DatasetAnalysisResults.avg_object_area', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='smallest_object_area', full_name='DatasetAnalysisResults.smallest_object_area', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='largest_object_area', full_name='DatasetAnalysisResults.largest_object_area', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_small_objects', full_name='DatasetAnalysisResults.num_small_objects', index=15,
      number=16, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_medium_objects', full_name='DatasetAnalysisResults.num_medium_objects', index=16,
      number=17, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_large_objects', full_name='DatasetAnalysisResults.num_large_objects', index=17,
      number=18, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_empty_images', full_name='DatasetAnalysisResults.num_empty_images', index=18,
      number=19, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_objects', full_name='DatasetAnalysisResults.total_objects', index=19,
      number=20, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duplicate_analysis', full_name='DatasetAnalysisResults.duplicate_analysis', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DATASETANALYSISRESULTS_LABELCOUNTSENTRY, _DATASETANALYSISRESULTS_LABELDISTRIBUTIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=384,
  serialized_end=1130,
)


_DUPLICATEANALYSIS = _descriptor.Descriptor(
  name='DuplicateAnalysis',
  full_name='DuplicateAnalysis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='duplicates', full_name='DuplicateAnalysis.duplicates', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duplicates_count', full_name='DuplicateAnalysis.duplicates_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_path_type', full_name='DuplicateAnalysis.image_path_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration_mins', full_name='DuplicateAnalysis.duration_mins', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1132,
  serialized_end=1245,
)


_SPLIT_LABELCOUNTENTRY = _descriptor.Descriptor(
  name='LabelCountEntry',
  full_name='Split.LabelCountEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Split.LabelCountEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='Split.LabelCountEntry.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1583,
  serialized_end=1632,
)

_SPLIT_LABELDISTRIBUTIONENTRY = _descriptor.Descriptor(
  name='LabelDistributionEntry',
  full_name='Split.LabelDistributionEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Split.LabelDistributionEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='Split.LabelDistributionEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1634,
  serialized_end=1690,
)

_SPLIT_IMAGESAMPLESENTRY = _descriptor.Descriptor(
  name='ImageSamplesEntry',
  full_name='Split.ImageSamplesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Split.ImageSamplesEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='Split.ImageSamplesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1692,
  serialized_end=1743,
)

_SPLIT = _descriptor.Descriptor(
  name='Split',
  full_name='Split',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='split_type', full_name='Split.split_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='Split.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cardinality', full_name='Split.cardinality', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_count', full_name='Split.label_count', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_distribution', full_name='Split.label_distribution', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_spec', full_name='Split.image_spec', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_classes', full_name='Split.num_classes', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='imbalanced', full_name='Split.imbalanced', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duplicates_count', full_name='Split.duplicates_count', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_samples', full_name='Split.image_samples', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SPLIT_LABELCOUNTENTRY, _SPLIT_LABELDISTRIBUTIONENTRY, _SPLIT_IMAGESAMPLESENTRY, ],
  enum_types=[
    _SPLIT_SPLITTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1248,
  serialized_end=1819,
)


_DATASETLEGACY_LABELCOUNTENTRY = _descriptor.Descriptor(
  name='LabelCountEntry',
  full_name='DatasetLegacy.LabelCountEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='DatasetLegacy.LabelCountEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='DatasetLegacy.LabelCountEntry.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1583,
  serialized_end=1632,
)

_DATASETLEGACY_LABELSMAPENTRY = _descriptor.Descriptor(
  name='LabelsMapEntry',
  full_name='DatasetLegacy.LabelsMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='DatasetLegacy.LabelsMapEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='DatasetLegacy.LabelsMapEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=333,
  serialized_end=381,
)

_DATASETLEGACY = _descriptor.Descriptor(
  name='DatasetLegacy',
  full_name='DatasetLegacy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='DatasetLegacy.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='DatasetLegacy.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='train_dataset', full_name='DatasetLegacy.train_dataset', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val_dataset', full_name='DatasetLegacy.val_dataset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='test_dataset', full_name='DatasetLegacy.test_dataset', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='full_dataset', full_name='DatasetLegacy.full_dataset', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cardinality', full_name='DatasetLegacy.cardinality', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_count', full_name='DatasetLegacy.label_count', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels_map', full_name='DatasetLegacy.labels_map', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='task', full_name='DatasetLegacy.task', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_classes', full_name='DatasetLegacy.num_classes', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='analysis_duration_mins', full_name='DatasetLegacy.analysis_duration_mins', index=11,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DATASETLEGACY_LABELCOUNTENTRY, _DATASETLEGACY_LABELSMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1822,
  serialized_end=2298,
)

_DATASET_LABELSMAPENTRY.containing_type = _DATASET
_DATASET.fields_by_name['labels_map'].message_type = _DATASET_LABELSMAPENTRY
_DATASET.fields_by_name['analysis_results'].message_type = _DATASETANALYSISRESULTS
_DATASET.fields_by_name['params'].message_type = masterful_dot_proto_dot_params__pb2._DATAPARAMS
_DATASETANALYSISRESULTS_LABELCOUNTSENTRY.containing_type = _DATASETANALYSISRESULTS
_DATASETANALYSISRESULTS_LABELDISTRIBUTIONSENTRY.containing_type = _DATASETANALYSISRESULTS
_DATASETANALYSISRESULTS.fields_by_name['label_counts'].message_type = _DATASETANALYSISRESULTS_LABELCOUNTSENTRY
_DATASETANALYSISRESULTS.fields_by_name['label_distributions'].message_type = _DATASETANALYSISRESULTS_LABELDISTRIBUTIONSENTRY
_DATASETANALYSISRESULTS.fields_by_name['duplicate_analysis'].message_type = _DUPLICATEANALYSIS
_SPLIT_LABELCOUNTENTRY.containing_type = _SPLIT
_SPLIT_LABELDISTRIBUTIONENTRY.containing_type = _SPLIT
_SPLIT_IMAGESAMPLESENTRY.containing_type = _SPLIT
_SPLIT.fields_by_name['split_type'].enum_type = _SPLIT_SPLITTYPE
_SPLIT.fields_by_name['label_count'].message_type = _SPLIT_LABELCOUNTENTRY
_SPLIT.fields_by_name['label_distribution'].message_type = _SPLIT_LABELDISTRIBUTIONENTRY
_SPLIT.fields_by_name['image_spec'].message_type = masterful_dot_proto_dot_metadata__pb2._IMAGESPEC
_SPLIT.fields_by_name['image_samples'].message_type = _SPLIT_IMAGESAMPLESENTRY
_SPLIT_SPLITTYPE.containing_type = _SPLIT
_DATASETLEGACY_LABELCOUNTENTRY.containing_type = _DATASETLEGACY
_DATASETLEGACY_LABELSMAPENTRY.containing_type = _DATASETLEGACY
_DATASETLEGACY.fields_by_name['train_dataset'].message_type = _SPLIT
_DATASETLEGACY.fields_by_name['val_dataset'].message_type = _SPLIT
_DATASETLEGACY.fields_by_name['test_dataset'].message_type = _SPLIT
_DATASETLEGACY.fields_by_name['full_dataset'].message_type = _SPLIT
_DATASETLEGACY.fields_by_name['label_count'].message_type = _DATASETLEGACY_LABELCOUNTENTRY
_DATASETLEGACY.fields_by_name['labels_map'].message_type = _DATASETLEGACY_LABELSMAPENTRY
_DATASETLEGACY.fields_by_name['task'].enum_type = masterful_dot_proto_dot_metadata__pb2._COMPUTERVISIONTASK
DESCRIPTOR.message_types_by_name['Dataset'] = _DATASET
DESCRIPTOR.message_types_by_name['DatasetAnalysisResults'] = _DATASETANALYSISRESULTS
DESCRIPTOR.message_types_by_name['DuplicateAnalysis'] = _DUPLICATEANALYSIS
DESCRIPTOR.message_types_by_name['Split'] = _SPLIT
DESCRIPTOR.message_types_by_name['DatasetLegacy'] = _DATASETLEGACY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Dataset = _reflection.GeneratedProtocolMessageType('Dataset', (_message.Message,), {

  'LabelsMapEntry' : _reflection.GeneratedProtocolMessageType('LabelsMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASET_LABELSMAPENTRY,
    '__module__' : 'masterful.proto.dataset_pb2'
    # @@protoc_insertion_point(class_scope:Dataset.LabelsMapEntry)
    })
  ,
  'DESCRIPTOR' : _DATASET,
  '__module__' : 'masterful.proto.dataset_pb2'
  # @@protoc_insertion_point(class_scope:Dataset)
  })
_sym_db.RegisterMessage(Dataset)
_sym_db.RegisterMessage(Dataset.LabelsMapEntry)

DatasetAnalysisResults = _reflection.GeneratedProtocolMessageType('DatasetAnalysisResults', (_message.Message,), {

  'LabelCountsEntry' : _reflection.GeneratedProtocolMessageType('LabelCountsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETANALYSISRESULTS_LABELCOUNTSENTRY,
    '__module__' : 'masterful.proto.dataset_pb2'
    # @@protoc_insertion_point(class_scope:DatasetAnalysisResults.LabelCountsEntry)
    })
  ,

  'LabelDistributionsEntry' : _reflection.GeneratedProtocolMessageType('LabelDistributionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETANALYSISRESULTS_LABELDISTRIBUTIONSENTRY,
    '__module__' : 'masterful.proto.dataset_pb2'
    # @@protoc_insertion_point(class_scope:DatasetAnalysisResults.LabelDistributionsEntry)
    })
  ,
  'DESCRIPTOR' : _DATASETANALYSISRESULTS,
  '__module__' : 'masterful.proto.dataset_pb2'
  # @@protoc_insertion_point(class_scope:DatasetAnalysisResults)
  })
_sym_db.RegisterMessage(DatasetAnalysisResults)
_sym_db.RegisterMessage(DatasetAnalysisResults.LabelCountsEntry)
_sym_db.RegisterMessage(DatasetAnalysisResults.LabelDistributionsEntry)

DuplicateAnalysis = _reflection.GeneratedProtocolMessageType('DuplicateAnalysis', (_message.Message,), {
  'DESCRIPTOR' : _DUPLICATEANALYSIS,
  '__module__' : 'masterful.proto.dataset_pb2'
  # @@protoc_insertion_point(class_scope:DuplicateAnalysis)
  })
_sym_db.RegisterMessage(DuplicateAnalysis)

Split = _reflection.GeneratedProtocolMessageType('Split', (_message.Message,), {

  'LabelCountEntry' : _reflection.GeneratedProtocolMessageType('LabelCountEntry', (_message.Message,), {
    'DESCRIPTOR' : _SPLIT_LABELCOUNTENTRY,
    '__module__' : 'masterful.proto.dataset_pb2'
    # @@protoc_insertion_point(class_scope:Split.LabelCountEntry)
    })
  ,

  'LabelDistributionEntry' : _reflection.GeneratedProtocolMessageType('LabelDistributionEntry', (_message.Message,), {
    'DESCRIPTOR' : _SPLIT_LABELDISTRIBUTIONENTRY,
    '__module__' : 'masterful.proto.dataset_pb2'
    # @@protoc_insertion_point(class_scope:Split.LabelDistributionEntry)
    })
  ,

  'ImageSamplesEntry' : _reflection.GeneratedProtocolMessageType('ImageSamplesEntry', (_message.Message,), {
    'DESCRIPTOR' : _SPLIT_IMAGESAMPLESENTRY,
    '__module__' : 'masterful.proto.dataset_pb2'
    # @@protoc_insertion_point(class_scope:Split.ImageSamplesEntry)
    })
  ,
  'DESCRIPTOR' : _SPLIT,
  '__module__' : 'masterful.proto.dataset_pb2'
  # @@protoc_insertion_point(class_scope:Split)
  })
_sym_db.RegisterMessage(Split)
_sym_db.RegisterMessage(Split.LabelCountEntry)
_sym_db.RegisterMessage(Split.LabelDistributionEntry)
_sym_db.RegisterMessage(Split.ImageSamplesEntry)

DatasetLegacy = _reflection.GeneratedProtocolMessageType('DatasetLegacy', (_message.Message,), {

  'LabelCountEntry' : _reflection.GeneratedProtocolMessageType('LabelCountEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETLEGACY_LABELCOUNTENTRY,
    '__module__' : 'masterful.proto.dataset_pb2'
    # @@protoc_insertion_point(class_scope:DatasetLegacy.LabelCountEntry)
    })
  ,

  'LabelsMapEntry' : _reflection.GeneratedProtocolMessageType('LabelsMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETLEGACY_LABELSMAPENTRY,
    '__module__' : 'masterful.proto.dataset_pb2'
    # @@protoc_insertion_point(class_scope:DatasetLegacy.LabelsMapEntry)
    })
  ,
  'DESCRIPTOR' : _DATASETLEGACY,
  '__module__' : 'masterful.proto.dataset_pb2'
  # @@protoc_insertion_point(class_scope:DatasetLegacy)
  })
_sym_db.RegisterMessage(DatasetLegacy)
_sym_db.RegisterMessage(DatasetLegacy.LabelCountEntry)
_sym_db.RegisterMessage(DatasetLegacy.LabelsMapEntry)


_DATASET_LABELSMAPENTRY._options = None
_DATASETANALYSISRESULTS_LABELCOUNTSENTRY._options = None
_DATASETANALYSISRESULTS_LABELDISTRIBUTIONSENTRY._options = None
_SPLIT_LABELCOUNTENTRY._options = None
_SPLIT_LABELDISTRIBUTIONENTRY._options = None
_SPLIT_IMAGESAMPLESENTRY._options = None
_DATASETLEGACY_LABELCOUNTENTRY._options = None
_DATASETLEGACY_LABELSMAPENTRY._options = None
# @@protoc_insertion_point(module_scope)



from django.db import models


class TrainingRun(models.Model):
  """Represents a full training run by Masterful.
  
  This model mirros the TrainingRun proto. All details are in proto definition.
  """
  # The name of the run.
  name = models.CharField(primary_key=True, max_length=250)

  # Datetime of when the training run was completed. We call it 'ts' to match
  # the proto name for ease of conversions, even though it's a datetime
  # field and not a timestamp.
  completed_ts = models.DateTimeField()

  # Information about the model. This is a Model proto json representation.
  model_info = models.JSONField(default=dict)

  # Results of searching for optimal policy and training with it. This is a
  # PolicySearchTask proto json representation.
  policy_search_results = models.JSONField(default=dict)

  # Name of the approach which performed the run.
  approach_name = models.CharField(max_length=120)

  # Version of the masterful pip package which produced the run.
  masterful_version = models.CharField(default="", max_length=100)

  # The CV task the run was used for.
  task = models.CharField(default="", max_length=100)

  # The absolute path of the model graph image on disk.
  model_graph_image = models.CharField(default="", max_length=100)

  # Optimization params used in training.
  optimization_params = models.JSONField(default=dict)

  # SSL params used in training.
  ssl_params = models.JSONField(default=dict)

  # Datasets used in this training run. Can also include evaluation (test) set
  # when CLI is used for the run.
  datasets = models.JSONField(default=dict)

  # Whether this run was a result of a CLI run.
  with_cli = models.BooleanField(default=False)


############
# DEPRECATED
############
class PolicySearchTask(models.Model):
  """The main PolicySearchTask model.
  
  The model mirrors the PolicySearchTask proto. Scalar fields are assigned
  similaer fields in the model, everything else is assigned JSON fields.
  """
  # The name of the policy. This is the primary key of the model.
  policy_name = models.CharField(primary_key=True, max_length=250)

  # The name of the approach.
  approach_name = models.CharField(max_length=120)

  # Node search tasks performed in the policy search task.
  node_search_tasks = models.JSONField(default=dict)

  # Metrics specific to the customer model without any Masterful improvements.
  presearch_model_val_metrics = models.JSONField(default=dict)

  # The version of the policy engine that produced this policy.
  engine_version = models.CharField(default="", max_length=100)

  # Whether fit results were captured.
  fit_was_captured = models.BooleanField(default=False)

  # Results of training the model with Masterful's learned policy.
  learned_policy_val_metrics = models.JSONField(default=dict)

  # The type of the ML task the policy is used for.
  task_type = models.CharField(default="COMPUTER_VISION_TASK_UNKNOWN",
                               max_length=250)


class Dataset(models.Model):
  """A model that represents a dataset.
  
  The model mirros the Dataset proto. For full documentation, see proto
  definition.
  """
  # The id of the dataset. This is the primary key of the model.
  dataset_id = models.CharField(primary_key=True, max_length=250)

  # The title of the dataset.
  title = models.CharField(max_length=250)

  # Train split. This is a Split proto.
  train_dataset = models.JSONField(default=dict)

  # Val split. This is a Split proto.
  val_dataset = models.JSONField(default=dict)

  # Test split. This is a Split proto.
  test_dataset = models.JSONField(default=dict)

  # Full dataset. This is a Split proto.
  full_dataset = models.JSONField(default=dict)

  # Cardinality of the whole dataset.
  cardinality = models.IntegerField(default=0)

  # Maps each label to its count in the full dataset.
  label_count = models.JSONField(default=dict)

  # Maps labels numeric format to their text format.
  labels_map = models.JSONField(default=dict)

  # Computer visiion task. This is a ComputerVisionTask proto.
  task = models.JSONField(default=dict)

  # Number of classes in the dataset.
  num_classes = models.IntegerField(default=0)

  # Duration it took to complete the dataset analysis, in minutes.
  analysis_duration_mins = models.FloatField(default=0.)


# Generated by Django 3.2.8 on 2022-04-27 14:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0007_policysearchtask_task_type'),
    ]

    operations = [
        migrations.CreateModel(
            name='Dataset',
            fields=[
                ('dataset_id', models.CharField(max_length=250, primary_key=True, serialize=False)),
                ('title', models.CharField(max_length=250)),
                ('train_dataset', models.JSONField(default=dict)),
                ('val_dataset', models.JSONField(default=dict)),
                ('test_dataset', models.JSONField(default=dict)),
                ('full_dataset', models.JSONField(default=dict)),
                ('cardinality', models.IntegerField(default=0)),
                ('label_count', models.JSONField(default=dict)),
                ('labels_map', models.JSONField(default=dict)),
                ('task', models.JSONField(default=dict)),
                ('num_classes', models.IntegerField(default=0)),
                ('analysis_duration_mins', models.FloatField(default=0.0)),
            ],
        ),
        migrations.DeleteModel(
            name='DatasetSpec',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: masterful/proto/training.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from masterful_gui.backend.proto import timestamp_pb2 as masterful_dot_proto_dot_timestamp__pb2
from masterful_gui.backend.proto import model_pb2 as masterful_dot_proto_dot_model__pb2
from masterful_gui.backend.proto import search_task_pb2 as masterful_dot_proto_dot_search__task__pb2
from masterful_gui.backend.proto import params_pb2 as masterful_dot_proto_dot_params__pb2
from masterful_gui.backend.proto import dataset_pb2 as masterful_dot_proto_dot_dataset__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='masterful/proto/training.proto',
    package='',
    syntax='proto3',
    serialized_options=None,
    serialized_pb=_b(
        '\n\x1emasterful/proto/training.proto\x1a\x1fmasterful/proto/timestamp.proto\x1a\x1bmasterful/proto/model.proto\x1a!masterful/proto/search_task.proto\x1a\x1cmasterful/proto/params.proto\x1a\x1dmasterful/proto/dataset.proto\"\xe1\x02\n\x0bTrainingRun\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x0c\x63ompleted_ts\x18\x02 \x01(\x0b\x32\n.Timestamp\x12\x1a\n\nmodel_info\x18\x03 \x01(\x0b\x32\x06.Model\x12\x30\n\x15policy_search_results\x18\x04 \x01(\x0b\x32\x11.PolicySearchTask\x12\x15\n\rapproach_name\x18\x05 \x01(\t\x12\x19\n\x11masterful_version\x18\x06 \x01(\t\x12\x0c\n\x04task\x18\x07 \x01(\t\x12\x30\n\x13optimization_params\x18\x08 \x01(\x0b\x32\x13.OptimizationParams\x12\x1e\n\nssl_params\x18\t \x01(\x0b\x32\n.SslParams\x12\x1a\n\x08\x64\x61tasets\x18\n \x03(\x0b\x32\x08.Dataset\x12\x14\n\x0csource_split\x18\x0b \x01(\t\x12\x10\n\x08with_cli\x18\x0c \x01(\x08\x62\x06proto3'
    ),
    dependencies=[
        masterful_dot_proto_dot_timestamp__pb2.DESCRIPTOR,
        masterful_dot_proto_dot_model__pb2.DESCRIPTOR,
        masterful_dot_proto_dot_search__task__pb2.DESCRIPTOR,
        masterful_dot_proto_dot_params__pb2.DESCRIPTOR,
        masterful_dot_proto_dot_dataset__pb2.DESCRIPTOR,
    ])

_TRAININGRUN = _descriptor.Descriptor(
    name='TrainingRun',
    full_name='TrainingRun',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(name='name',
                                    full_name='TrainingRun.name',
                                    index=0,
                                    number=1,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='completed_ts',
                                    full_name='TrainingRun.completed_ts',
                                    index=1,
                                    number=2,
                                    type=11,
                                    cpp_type=10,
                                    label=1,
                                    has_default_value=False,
                                    default_value=None,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='model_info',
                                    full_name='TrainingRun.model_info',
                                    index=2,
                                    number=3,
                                    type=11,
                                    cpp_type=10,
                                    label=1,
                                    has_default_value=False,
                                    default_value=None,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='policy_search_results',
            full_name='TrainingRun.policy_search_results',
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='approach_name',
                                    full_name='TrainingRun.approach_name',
                                    index=4,
                                    number=5,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='masterful_version',
                                    full_name='TrainingRun.masterful_version',
                                    index=5,
                                    number=6,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='task',
                                    full_name='TrainingRun.task',
                                    index=6,
                                    number=7,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='optimization_params',
                                    full_name='TrainingRun.optimization_params',
                                    index=7,
                                    number=8,
                                    type=11,
                                    cpp_type=10,
                                    label=1,
                                    has_default_value=False,
                                    default_value=None,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='ssl_params',
                                    full_name='TrainingRun.ssl_params',
                                    index=8,
                                    number=9,
                                    type=11,
                                    cpp_type=10,
                                    label=1,
                                    has_default_value=False,
                                    default_value=None,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='datasets',
                                    full_name='TrainingRun.datasets',
                                    index=9,
                                    number=10,
                                    type=11,
                                    cpp_type=10,
                                    label=3,
                                    has_default_value=False,
                                    default_value=[],
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='source_split',
                                    full_name='TrainingRun.source_split',
                                    index=10,
                                    number=11,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='with_cli',
                                    full_name='TrainingRun.with_cli',
                                    index=11,
                                    number=12,
                                    type=8,
                                    cpp_type=7,
                                    label=1,
                                    has_default_value=False,
                                    default_value=False,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=193,
    serialized_end=546,
)

_TRAININGRUN.fields_by_name[
    'completed_ts'].message_type = masterful_dot_proto_dot_timestamp__pb2._TIMESTAMP
_TRAININGRUN.fields_by_name[
    'model_info'].message_type = masterful_dot_proto_dot_model__pb2._MODEL
_TRAININGRUN.fields_by_name[
    'policy_search_results'].message_type = masterful_dot_proto_dot_search__task__pb2._POLICYSEARCHTASK
_TRAININGRUN.fields_by_name[
    'optimization_params'].message_type = masterful_dot_proto_dot_params__pb2._OPTIMIZATIONPARAMS
_TRAININGRUN.fields_by_name[
    'ssl_params'].message_type = masterful_dot_proto_dot_params__pb2._SSLPARAMS
_TRAININGRUN.fields_by_name[
    'datasets'].message_type = masterful_dot_proto_dot_dataset__pb2._DATASET
DESCRIPTOR.message_types_by_name['TrainingRun'] = _TRAININGRUN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TrainingRun = _reflection.GeneratedProtocolMessageType(
    'TrainingRun',
    (_message.Message,),
    {
        'DESCRIPTOR': _TRAININGRUN,
        '__module__': 'masterful.proto.training_pb2'
        # @@protoc_insertion_point(class_scope:TrainingRun)
    })
_sym_db.RegisterMessage(TrainingRun)

# @@protoc_insertion_point(module_scope)



"""Defines Visualize's dataset proto scanner functionality.

This module implements the functionality for Visualzie to scan for
serialized dataset_pb2.DatasetLegacy serialized protos produced by
Masterful.
"""

import os
import pathlib

import google.protobuf.json_format as json_format

from masterful_gui.backend.apps.api import models
from masterful_gui.backend.proto import dataset_pb2

# The location where the scanner should look for serialzed protos.
_SCAN_DIR = f'{os.path.expanduser("~")}/.masterful/datasets'

# The extension of a serialized policy proto file. The extension actually
# makes no difference, this is just to facilitate identifying the right files
# to read.
# WARNING: This matches the configuration of proto_serializer module in
# masterful_partners repo. You must change them both or you'll break
# assumptions and Visualize.
_EXTENSION = "dspb"


def scan():
  """Scans the configured directory for serlized dataset protos.
  
  This function deserializes dataset protos on disk, converts them
  to Django's owm dataset spec model, and persists them to the database
  (app model).
  If the database already had a record for that dataset, it updates
  that records with the values extracted from the serialized dataset. If
  it wasn't, this will persist it to the database.
  """
  pathlib.Path(_SCAN_DIR).mkdir(parents=True, exist_ok=True)

  if len(os.listdir(_SCAN_DIR)) == 0:
    #TODO(ray): Consider printing something to show in backend logs.
    return

  serialized_protos = []
  for file in os.listdir(_SCAN_DIR):
    if file.split('.')[-1] != _EXTENSION:
      continue
    serialized_protos.append(file)

  if len(serialized_protos) == 0:
    return

  for serialized_proto in serialized_protos:
    proto = dataset_pb2.DatasetLegacy()
    file_name = f'{_SCAN_DIR}/{serialized_proto}'
    with open(file_name, "rb") as f:
      proto.ParseFromString(f.read())

    proto_dict = json_format.MessageToDict(proto,
                                           use_integers_for_enums=False,
                                           including_default_value_fields=True,
                                           preserving_proto_field_name=True)

    model_exists = len(models.Dataset.objects.filter(pk=proto.id)) > 0
    if model_exists:
      existing_model = models.Dataset.objects.get(pk=proto.id)
      existing_model.title = proto.title
      existing_model.train_dataset = proto_dict.get("train_dataset", {})
      existing_model.val_dataset = proto_dict.get("val_dataset", {})
      existing_model.test_dataset = proto_dict.get("test_dataset", {})
      existing_model.full_dataset = proto_dict.get("full_dataset", {})
      existing_model.cardinality = proto.cardinality
      existing_model.label_count = proto_dict.get("label_count", {})
      existing_model.labels_map = proto_dict.get("labels_map", {})
      existing_model.task = proto_dict.get("task", {})
      existing_model.num_classes = proto.num_classes
      existing_model.analysis_duration_mins = proto.analysis_duration_mins

      existing_model.save()

    else:
      new_model = models.Dataset.objects.create(
          dataset_id=proto.id,
          title=proto.title,
          train_dataset=proto_dict.get("train_dataset", {}),
          val_dataset=proto_dict.get("val_dataset", {}),
          test_dataset=proto_dict.get("test_dataset", {}),
          full_dataset=proto_dict.get("full_dataset", {}),
          cardinality=proto.cardinality,
          label_count=proto_dict.get("label_count", {}),
          labels_map=proto_dict.get("labels_map", {}),
          task=proto_dict.get("task", {}),
          num_classes=proto.num_classes,
          analysis_duration_mins=proto.analysis_duration_mins)
      new_model.save()


"""Pip package configuration module."""

import os
from setuptools import setup, find_packages

import masterful_gui.version as version

with open("README.md", "r") as f:
  _LONG_DESCRIPTION = f.read()


def get_required_packages():
  file_path = f"{os.getcwd()}/requirements.txt"
  with open(file_path) as f:
    return f.read().splitlines()


REQUIRED_PACKAGES = get_required_packages()

# The script that defines the command to run the GUI.
CONSOLE_SCRIPTS = [
    "masterful-gui = masterful_gui.main:run_main",
]

setup(
    name='masterful-gui',
    version=version.__version__,
    author="Masterful AI",
    author_email="help@masterfulai.com",
    description="Masterful AutoML Platform GUI.",
    long_description=_LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    url="https://masterfulai.com",
    license='Copyright 2022, Masterful AI, Inc.',
    license_files=('LICENSE',),
    packages=find_packages(),
    entry_points={
        "console_scripts": CONSOLE_SCRIPTS,
    },
    install_requires=REQUIRED_PACKAGES,
    include_package_data=True,
    package_data={'': ['data/*']},
    python_requires=">=3.6",
)



# Generated by Django 3.2.8 on 2022-07-27 14:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0011_trainingrun_model_graph_image'),
    ]

    operations = [
        migrations.AddField(
            model_name='trainingrun',
            name='optimization_params',
            field=models.JSONField(default=dict),
        ),
        migrations.AddField(
            model_name='trainingrun',
            name='ssl_params',
            field=models.JSONField(default=dict),
        ),
    ]



"""Handles creating images from binary image data."""

import os
import pathlib

from masterful_gui.backend.apps.api import constants
from masterful_gui.backend.proto import model_pb2
from django.conf import settings


def save_model_graph_image(run_name: str,
                           model_graph: model_pb2.ModelGraphImage) -> str:
  """Saves the model graph image in backend's media storage and returns URL.
  
  Args:
    run_name: The name of the training run.
    model_graph: The proto of the model graph image holding the data.
  
  Returns:
    The URL of the saved image on success. This URL is for the image as it's
    served by the Django backend server that the frontend can use to render
    the image.
  """
  if not model_graph.graph_was_rendered:
    return ""

  file_name = f"{constants.MODEL_GRAPH_IMAGE_NAME}.png"
  output_subdir = f"{run_name}/{constants.MODEL_IMG_DIR}"
  output_dir = f"{settings.MEDIA_ROOT}/{output_subdir}/"

  pathlib.Path(output_dir).mkdir(parents=True, exist_ok=True)

  full_path = f'{output_dir}/{file_name}'
  with open(full_path, 'wb') as f:
    f.write(model_graph.data)

  url = ''
  if settings.DEBUG:
    url = f'http://localhost:7007/media/{output_subdir}/{file_name}'
  else:
    url = f'http://localhost:7007/static/media/{output_subdir}/{file_name}'

  return url



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: masterful/proto/model.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from masterful_gui.backend.proto import params_pb2 as masterful_dot_proto_dot_params__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='masterful/proto/model.proto',
    package='',
    syntax='proto3',
    serialized_options=None,
    serialized_pb=_b(
        '\n\x1bmasterful/proto/model.proto\x1a\x1cmasterful/proto/params.proto\"\x89\x01\n\x05Model\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x30\n\x13\x61rchitecture_params\x18\x02 \x01(\x0b\x32\x13.ArchitectureParams\x12\x19\n\x07summary\x18\x03 \x01(\x0b\x32\x08.Summary\x12%\n\x0bgraph_image\x18\x04 \x01(\x0b\x32\x10.ModelGraphImage\"i\n\nSummaryRow\x12\r\n\x05layer\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x14\n\x0coutput_shape\x18\x03 \x01(\t\x12\x12\n\nnum_params\x18\x04 \x01(\t\x12\x14\n\x0c\x63onnected_to\x18\x05 \x01(\t\"#\n\x07Summary\x12\x18\n\x03row\x18\x01 \x03(\x0b\x32\x0b.SummaryRow\"v\n\x0fModelGraphImage\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x1a\n\x12graph_was_rendered\x18\x02 \x01(\x08\x12\x1c\n\x14graph_import_failure\x18\x03 \x01(\x08\x12\x1b\n\x13graph_failure_error\x18\x04 \x01(\tb\x06proto3'
    ),
    dependencies=[
        masterful_dot_proto_dot_params__pb2.DESCRIPTOR,
    ])

_MODEL = _descriptor.Descriptor(
    name='Model',
    full_name='Model',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(name='name',
                                    full_name='Model.name',
                                    index=0,
                                    number=1,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='architecture_params',
                                    full_name='Model.architecture_params',
                                    index=1,
                                    number=2,
                                    type=11,
                                    cpp_type=10,
                                    label=1,
                                    has_default_value=False,
                                    default_value=None,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='summary',
                                    full_name='Model.summary',
                                    index=2,
                                    number=3,
                                    type=11,
                                    cpp_type=10,
                                    label=1,
                                    has_default_value=False,
                                    default_value=None,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='graph_image',
                                    full_name='Model.graph_image',
                                    index=3,
                                    number=4,
                                    type=11,
                                    cpp_type=10,
                                    label=1,
                                    has_default_value=False,
                                    default_value=None,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=62,
    serialized_end=199,
)

_SUMMARYROW = _descriptor.Descriptor(
    name='SummaryRow',
    full_name='SummaryRow',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(name='layer',
                                    full_name='SummaryRow.layer',
                                    index=0,
                                    number=1,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='type',
                                    full_name='SummaryRow.type',
                                    index=1,
                                    number=2,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='output_shape',
                                    full_name='SummaryRow.output_shape',
                                    index=2,
                                    number=3,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='num_params',
                                    full_name='SummaryRow.num_params',
                                    index=3,
                                    number=4,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='connected_to',
                                    full_name='SummaryRow.connected_to',
                                    index=4,
                                    number=5,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=201,
    serialized_end=306,
)

_SUMMARY = _descriptor.Descriptor(
    name='Summary',
    full_name='Summary',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(name='row',
                                    full_name='Summary.row',
                                    index=0,
                                    number=1,
                                    type=11,
                                    cpp_type=10,
                                    label=3,
                                    has_default_value=False,
                                    default_value=[],
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=308,
    serialized_end=343,
)

_MODELGRAPHIMAGE = _descriptor.Descriptor(
    name='ModelGraphImage',
    full_name='ModelGraphImage',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(name='data',
                                    full_name='ModelGraphImage.data',
                                    index=0,
                                    number=1,
                                    type=12,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b(""),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='graph_was_rendered',
            full_name='ModelGraphImage.graph_was_rendered',
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='graph_import_failure',
            full_name='ModelGraphImage.graph_import_failure',
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='graph_failure_error',
            full_name='ModelGraphImage.graph_failure_error',
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=345,
    serialized_end=463,
)

_MODEL.fields_by_name[
    'architecture_params'].message_type = masterful_dot_proto_dot_params__pb2._ARCHITECTUREPARAMS
_MODEL.fields_by_name['summary'].message_type = _SUMMARY
_MODEL.fields_by_name['graph_image'].message_type = _MODELGRAPHIMAGE
_SUMMARY.fields_by_name['row'].message_type = _SUMMARYROW
DESCRIPTOR.message_types_by_name['Model'] = _MODEL
DESCRIPTOR.message_types_by_name['SummaryRow'] = _SUMMARYROW
DESCRIPTOR.message_types_by_name['Summary'] = _SUMMARY
DESCRIPTOR.message_types_by_name['ModelGraphImage'] = _MODELGRAPHIMAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Model = _reflection.GeneratedProtocolMessageType(
    'Model',
    (_message.Message,),
    {
        'DESCRIPTOR': _MODEL,
        '__module__': 'masterful.proto.model_pb2'
        # @@protoc_insertion_point(class_scope:Model)
    })
_sym_db.RegisterMessage(Model)

SummaryRow = _reflection.GeneratedProtocolMessageType(
    'SummaryRow',
    (_message.Message,),
    {
        'DESCRIPTOR': _SUMMARYROW,
        '__module__': 'masterful.proto.model_pb2'
        # @@protoc_insertion_point(class_scope:SummaryRow)
    })
_sym_db.RegisterMessage(SummaryRow)

Summary = _reflection.GeneratedProtocolMessageType(
    'Summary',
    (_message.Message,),
    {
        'DESCRIPTOR': _SUMMARY,
        '__module__': 'masterful.proto.model_pb2'
        # @@protoc_insertion_point(class_scope:Summary)
    })
_sym_db.RegisterMessage(Summary)

ModelGraphImage = _reflection.GeneratedProtocolMessageType(
    'ModelGraphImage',
    (_message.Message,),
    {
        'DESCRIPTOR': _MODELGRAPHIMAGE,
        '__module__': 'masterful.proto.model_pb2'
        # @@protoc_insertion_point(class_scope:ModelGraphImage)
    })
_sym_db.RegisterMessage(ModelGraphImage)

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: masterful/proto/action.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='masterful/proto/action.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1cmasterful/proto/action.proto*\xe1\x03\n\nActionName\x12\x17\n\x13\x41\x43TION_NAME_UNKNOWN\x10\x00\x12\r\n\tROTATE_90\x10\x01\x12\n\n\x06ROTATE\x10\x02\x12\x0f\n\x0bRAISE_COLOR\x10\x03\x12\x0f\n\x0bLOWER_COLOR\x10\x04\x12\x12\n\x0eRAISE_CONTRAST\x10\x05\x12\x12\n\x0eLOWER_CONTRAST\x10\x06\x12\x14\n\x10RAISE_BRIGHTNESS\x10\x07\x12\x14\n\x10LOWER_BRIGHTNESS\x10\x08\x12\x13\n\x0fRAISE_SHARPNESS\x10\t\x12\x13\n\x0fLOWER_SHARPNESS\x10\n\x12\x11\n\rAUTO_CONTRAST\x10\x0b\x12\x0c\n\x08SOLARIZE\x10\x0c\x12\r\n\tPOSTERIZE\x10\r\x12\x0c\n\x08\x45QUALIZE\x10\x0e\x12\x12\n\x0eVERTICAL_SHEAR\x10\x0f\x12\x14\n\x10HORIZONTAL_SHEAR\x10\x10\x12\x18\n\x14HORIZONTAL_TRANSLATE\x10\x11\x12\x16\n\x12VERTICAL_TRANSLATE\x10\x12\x12\n\n\x06\x43UTMIX\x10\x13\x12\t\n\x05MIXUP\x10\x14\x12\x07\n\x03LSR\x10\x15\x12\x15\n\x11HORIZONTAL_MIRROR\x10\x16\x12\x0e\n\nJITTER_HUE\x10\x17\x12\x0e\n\nRAISE_ZOOM\x10\x18\x12\x0e\n\nLOWER_ZOOM\x10\x19\x62\x06proto3')
)

_ACTIONNAME = _descriptor.EnumDescriptor(
  name='ActionName',
  full_name='ActionName',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTION_NAME_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROTATE_90', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROTATE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RAISE_COLOR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOWER_COLOR', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RAISE_CONTRAST', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOWER_CONTRAST', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RAISE_BRIGHTNESS', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOWER_BRIGHTNESS', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RAISE_SHARPNESS', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOWER_SHARPNESS', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTO_CONTRAST', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOLARIZE', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POSTERIZE', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EQUALIZE', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERTICAL_SHEAR', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HORIZONTAL_SHEAR', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HORIZONTAL_TRANSLATE', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERTICAL_TRANSLATE', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUTMIX', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MIXUP', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LSR', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HORIZONTAL_MIRROR', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JITTER_HUE', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RAISE_ZOOM', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOWER_ZOOM', index=25, number=25,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=33,
  serialized_end=514,
)
_sym_db.RegisterEnumDescriptor(_ACTIONNAME)

ActionName = enum_type_wrapper.EnumTypeWrapper(_ACTIONNAME)
ACTION_NAME_UNKNOWN = 0
ROTATE_90 = 1
ROTATE = 2
RAISE_COLOR = 3
LOWER_COLOR = 4
RAISE_CONTRAST = 5
LOWER_CONTRAST = 6
RAISE_BRIGHTNESS = 7
LOWER_BRIGHTNESS = 8
RAISE_SHARPNESS = 9
LOWER_SHARPNESS = 10
AUTO_CONTRAST = 11
SOLARIZE = 12
POSTERIZE = 13
EQUALIZE = 14
VERTICAL_SHEAR = 15
HORIZONTAL_SHEAR = 16
HORIZONTAL_TRANSLATE = 17
VERTICAL_TRANSLATE = 18
CUTMIX = 19
MIXUP = 20
LSR = 21
HORIZONTAL_MIRROR = 22
JITTER_HUE = 23
RAISE_ZOOM = 24
LOWER_ZOOM = 25


DESCRIPTOR.enum_types_by_name['ActionName'] = _ACTIONNAME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


# @@protoc_insertion_point(module_scope)



# Generated by Django 3.2.8 on 2022-10-19 12:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0013_trainingrun_datasets'),
    ]

    operations = [
        migrations.AddField(
            model_name='trainingrun',
            name='with_cli',
            field=models.BooleanField(default=False),
        ),
    ]
